/* tslint:disable */
/* eslint-disable */
/**
* Noise reduction. 
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to sharpen an image:
* use photon::conv::sharpen;
* photon::channels::sharpen(img);
* ```
* Adds a constant to a select R, G, or B channel\'s value.
* @param {PhotonImage} photon_image 
*/
export function noise_reduction(photon_image: PhotonImage): void;
/**
* Sharpen an image. 
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to sharpen an image:
* use photon::conv::sharpen;
* photon::channels::sharpen(img);
* ```
* Adds a constant to a select R, G, or B channel\'s value.
* @param {PhotonImage} photon_image 
*/
export function sharpen(photon_image: PhotonImage): void;
/**
* Apply edge detection to an image, to create a dark version with its edges highlighted.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to increase the Red channel for all pixels by 10:
* use photon::channels;
* photon::conv::edge_detection(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function edge_detection(photon_image: PhotonImage): void;
/**
* Apply an identity kernel convolution to an image.
* 
* # Arguments
* * `img` -A PhotonImage.
* 
* # Example
*
* ```
* // For example, to apply an identity kernel convolution:
* use photon::channels;
* photon::conv::identity(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function identity(photon_image: PhotonImage): void;
/**
* Apply a box blur effect.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to apply a box blur effect:
* use photon::channels;
* photon::conv::box_blur(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function box_blur(photon_image: PhotonImage): void;
/**
* Gaussian blur in linear time.
* 
* Reference: http://blog.ivank.net/fastest-gaussian-blur.html
*
* # Arguments
* * `photon_image` - A PhotonImage
* * `radius` - blur radius
* # Example
*
* ```
* photon::conv:fast_gaussian_blur(photon_image, 3);
* ```
* @param {PhotonImage} photon_image 
* @param {number} radius 
*/
export function gaussian_blur(photon_image: PhotonImage, radius: number): void;
/**
* Detect horizontal lines in an image, and highlight these only.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to display the horizontal lines in an image:
* use photon::channels;
* photon::conv::detect_horizontal_lines(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function detect_horizontal_lines(photon_image: PhotonImage): void;
/**
* Detect vertical lines in an image, and highlight these only.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to display the vertical lines in an image:
* use photon::channels;
* photon::conv::detect_vertical_lines(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function detect_vertical_lines(photon_image: PhotonImage): void;
/**
* Detect lines at a forty five degree angle in an image, and highlight these only.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to display the lines at a forty five degree angle in an image:
* use photon::channels;
* photon::conv::detect_fortyfivedeg_lines(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function detect_45_deg_lines(photon_image: PhotonImage): void;
/**
* Detect lines at a 135 degree angle in an image, and highlight these only.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to display the lines at a 135 degree angle in an image:
* use photon::channels;
* photon::conv::detect_hundredthirtyfive_deg_lines(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function detect_135_deg_lines(photon_image: PhotonImage): void;
/**
* Apply a standard laplace convolution.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to apply a laplace effect:
* use photon::conv;
* photon::conv::laplace(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function laplace(photon_image: PhotonImage): void;
/**
* Preset edge effect.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to apply this effect:
* use photon::conv;
* photon::conv::edge_one(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function edge_one(photon_image: PhotonImage): void;
/**
* Apply an emboss effect to an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to apply an emboss effect:
* use photon::conv;
* photon::conv::emboss(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function emboss(photon_image: PhotonImage): void;
/**
* Apply a horizontal Sobel filter to an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to apply a horizontal Sobel filter:
* use photon::conv;
* photon::conv::sobel_horizontal(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function sobel_horizontal(photon_image: PhotonImage): void;
/**
* Apply a horizontal Prewitt convolution to an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to apply a horizontal Prewitt convolution effect:
* use photon::conv;
* photon::conv::prewitt_horizontal(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function prewitt_horizontal(photon_image: PhotonImage): void;
/**
* Apply a vertical Sobel filter to an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* # Example
*
* ```
* // For example, to apply a vertical Sobel filter:
* use photon::conv;
* photon::conv::sobel_vertical(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function sobel_vertical(photon_image: PhotonImage): void;
/**
* Alter a select channel by incrementing or decrementing its value by a constant.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `channel` - The channel you wish to alter, it should be either 0, 1 or 2, 
* representing R, G, or B respectively. (O=Red, 1=Green, 2=Blue)
* * `amount` - The amount to increment/decrement the channel\'s value by for that pixel.
* A positive value will increment/decrement the channel\'s value, a negative value will decrement the channel\'s value.
* 
* ## Example
*
* ```
* // For example, to increase the Red channel for all pixels by 10:
* use photon::channels;
* let img = photon::open_image(\"img.jpg\");
* photon::channels::alter_channel(&mut img, 0, 10);
* // Write the contents of this image in JPG format.
* photon::helpers::save_image(img, \"new_image.png\");
* ```
* 
* Adds a constant to a select R, G, or B channel\'s value.
* 
* ### Decrease a channel\'s value
* // For example, to decrease the Green channel for all pixels by 20:
* ```
* use photon::channels;
* photon::channels::alter_channel(&mut img, 1, -20);
* ```
* **Note**: Note the use of a minus symbol when decreasing the channel. 
* @param {PhotonImage} img 
* @param {number} channel 
* @param {number} amt 
*/
export function alter_channel(img: PhotonImage, channel: number, amt: number): void;
/**
* Increment or decrement every pixel\'s Red channel by a constant.
* 
* # Arguments
* * `img` - A PhotonImage. See the PhotonImage struct for details.
* * `amt` - The amount to increment or decrement the channel\'s value by for that pixel.
* 
* # Example
*
* ```
* // For example, to increase the Red channel for all pixels by 10:
* use photon::channels;
* photon::channels::alter_red_channel(&mut img, 10);
* ```
* @param {PhotonImage} photon_image 
* @param {number} amt 
*/
export function alter_red_channel(photon_image: PhotonImage, amt: number): void;
/**
* Increment or decrement every pixel\'s Green channel by a constant.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `amt` - The amount to increment/decrement the channel\'s value by for that pixel.
* 
* # Example
*
* ```
* // For example, to increase the Green channel for all pixels by 20:
* use photon::channels;
* photon::channels::alter_green_channel(&mut img, 10);
* ```
* @param {PhotonImage} img 
* @param {number} amt 
*/
export function alter_green_channel(img: PhotonImage, amt: number): void;
/**
* Increment or decrement every pixel\'s Blue channel by a constant.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `amt` - The amount to increment or decrement the channel\'s value by for that pixel.
* 
* # Example
*
* ```
* // For example, to increase the Blue channel for all pixels by 10:
* use photon::channels;
* photon::channels::alter_blue_channel(&mut img, 10);
* ```
* @param {PhotonImage} img 
* @param {number} amt 
*/
export function alter_blue_channel(img: PhotonImage, amt: number): void;
/**
* Increment/decrement two channels\' values simultaneously by adding an amt to each channel per pixel.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `channel1` - A usize from 0 to 2 that represents either the R, G or B channels.
* * `amt1` - The amount to increment/decrement the channel\'s value by for that pixel.
* * `channel2` -A usize from 0 to 2 that represents either the R, G or B channels.
* * `amt2` - The amount to increment/decrement the channel\'s value by for that pixel.
* 
* # Example
*
* ```
* // For example, to increase the values of the Red and Blue channels per pixel:
* photon::channels::inc_two_channels(&mut img, 0, 10, 2, 20);
* ```
* @param {PhotonImage} img 
* @param {number} channel1 
* @param {number} amt1 
* @param {number} channel2 
* @param {number} amt2 
*/
export function alter_two_channels(img: PhotonImage, channel1: number, amt1: number, channel2: number, amt2: number): void;
/**
* Increment all 3 channels\' values by adding an amt to each channel per pixel.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `r_amt` - The amount to increment/decrement the Red channel by.
* * `g_amt` - The amount to increment/decrement the Green channel by.
* * `b_amt` - The amount to increment/decrement the Blue channel by. 
* 
* # Example
*
* ```
* // For example, to increase the values of the Red channel by 10, the Green channel by 20, 
* // and the Blue channel by 50:
* // photon::channels::alter_channels(&mut img, 10, 20, 50);
* ```
* @param {PhotonImage} img 
* @param {number} r_amt 
* @param {number} g_amt 
* @param {number} b_amt 
*/
export function alter_channels(img: PhotonImage, r_amt: number, g_amt: number, b_amt: number): void;
/**
* Set a certain channel to zero, thus removing the channel\'s influence in the pixels\' final rendered colour.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `channel` - The channel to be removed; must be a usize from 0 to 2, with 0 representing Red, 1 representing Green, and 2 representing Blue.
* * `min_filter` - Minimum filter. Value between 0 and 255. Only remove the channel if the current pixel\'s channel value is less than this minimum filter. To completely 
* remove the channel, set this value to 255, to leave the channel as is, set to 0, and to set a channel to zero for a pixel whose red value is greater than 50, 
* then channel would be 0 and min_filter would be 50.
* 
* # Example
*
* ```
* // For example, to remove the Red channel with a min_filter of 100:
* photon::channels::remove_channel(&mut img, 0, 100);
* ```
* @param {PhotonImage} img 
* @param {number} channel 
* @param {number} min_filter 
*/
export function remove_channel(img: PhotonImage, channel: number, min_filter: number): void;
/**
* Remove the Red channel\'s influence in an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `min_filter` - Only remove the channel if the current pixel\'s channel value is less than this minimum filter. 
* 
* # Example
*
* ```
* // For example, to remove the red channel for red channel pixel values less than 50:
* photon::channels::remove_red_channel(&mut img, 50);
* ```
* @param {PhotonImage} img 
* @param {number} min_filter 
*/
export function remove_red_channel(img: PhotonImage, min_filter: number): void;
/**
* Remove the Green channel\'s influence in an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `min_filter` - Only remove the channel if the current pixel\'s channel value is less than this minimum filter. 
* 
* # Example
*
* ```
* // For example, to remove the green channel for green channel pixel values less than 50:
* photon::channels::remove_green_channel(img, 50);
* ```
* @param {PhotonImage} img 
* @param {number} min_filter 
*/
export function remove_green_channel(img: PhotonImage, min_filter: number): void;
/**
* Remove the Blue channel\'s influence in an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `min_filter` - Only remove the channel if the current pixel\'s channel value is less than this minimum filter. 
* 
* # Example
*
* ```
* // For example, to remove the blue channel for blue channel pixel values less than 50:
* photon::channels::remove_blue_channel(&mut img, 50);
* ```
* @param {PhotonImage} img 
* @param {number} min_filter 
*/
export function remove_blue_channel(img: PhotonImage, min_filter: number): void;
/**
* Swap two channels.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `channel1` - An index from 0 to 2, representing the Red, Green or Blue channels respectively. Red would be represented by 0, Green by 1, and Blue by 2.
* * `channel2` - An index from 0 to 2, representing the Red, Green or Blue channels respectively. Same as above.
* 
* # Example
*
* ```
* // For example, to swap the values of the Red channel with the values of the Blue channel:
* photon::channels::swap_channels(&mut img, 0, 2);
* ```
* @param {PhotonImage} img 
* @param {number} channel1 
* @param {number} channel2 
*/
export function swap_channels(img: PhotonImage, channel1: number, channel2: number): void;
/**
* Selective hue rotation.
* 
* Only rotate the hue of a pixel if its RGB values are within a specified range.
* This function only rotates a pixel\'s hue to another  if it is visually similar to the colour specified.
* For example, if a user wishes all pixels that are blue to be changed to red, they can selectively specify  only the blue pixels to be changed.
* # Arguments
* * `img` - A PhotonImage.
* * `ref_color` - The `RGB` value of the reference color (to be compared to)
* * `degrees` - The amount of degrees to hue rotate by.
* 
* # Example
*
* ```
* // For example, to only rotate the pixels that are of RGB value RGB{20, 40, 60}:
* let ref_color = Rgb{20, 40, 60};
* photon::channels::selective_hue_rotate(&mut img, ref_color, 180);
* ```
* @param {PhotonImage} photon_image 
* @param {Rgb} ref_color 
* @param {number} degrees 
*/
export function selective_hue_rotate(photon_image: PhotonImage, ref_color: Rgb, degrees: number): void;
/**
* Invert RGB value of an image.
*
* # Arguments
* * `photon_image` - A DynamicImage that contains a view into the image.
* # Example
*
* ```
* photon::channels::invert(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function invert(photon_image: PhotonImage): void;
/**
* Selectively lighten an image.
* 
* Only lighten the hue of a pixel if its colour matches or is similar to the RGB colour specified.
* For example, if a user wishes all pixels that are blue to be lightened, they can selectively specify  only the blue pixels to be changed.
* # Arguments
* * `img` - A PhotonImage.
* * `ref_color` - The `RGB` value of the reference color (to be compared to)
* * `amt` - The level from 0 to 1 to lighten the hue by. Increasing by 10% would have an `amt` of 0.1
* 
* # Example
*
* ```
* // For example, to only lighten the pixels that are of or similar to RGB value RGB{20, 40, 60}:
* let ref_color = Rgb{20, 40, 60};
* photon::channels::selective_lighten(&mut img, ref_color, 0.2);
* ```
* @param {PhotonImage} img 
* @param {Rgb} ref_color 
* @param {number} amt 
*/
export function selective_lighten(img: PhotonImage, ref_color: Rgb, amt: number): void;
/**
* Selectively desaturate pixel colours which are similar to the reference colour provided.
* 
* Similarity between two colours is calculated via the CIE76 formula.
* Only desaturates the hue of a pixel if its similarity to the reference colour is within the range in the algorithm.
* For example, if a user wishes all pixels that are blue to be desaturated by 0.1, they can selectively specify  only the blue pixels to be changed.
* # Arguments
* * `img` - A PhotonImage.
* * `ref_color` - The `RGB` value of the reference color (to be compared to)
* * `amt` - The amount of desaturate the colour by. 
* 
* # Example
*
* ```
* // For example, to only desaturate the pixels that are similar to the RGB value RGB{20, 40, 60}:
* let ref_color = Rgb{20, 40, 60};
* photon::channels::selective_desaturate(&mut img, ref_color, 0.1);
* ```
* @param {PhotonImage} img 
* @param {Rgb} ref_color 
* @param {number} amt 
*/
export function selective_desaturate(img: PhotonImage, ref_color: Rgb, amt: number): void;
/**
* Selectively saturate pixel colours which are similar to the reference colour provided.
* 
* Similarity between two colours is calculated via the CIE76 formula.
* Only saturates the hue of a pixel if its similarity to the reference colour is within the range in the algorithm.
* For example, if a user wishes all pixels that are blue to have an increase in saturation by 10%, they can selectively specify only the blue pixels to be changed.
* # Arguments
* * `img` - A PhotonImage.
* * `ref_color` - The `RGB` value of the reference color (to be compared to)
* * `amt` - The amount of saturate the colour by. 
* 
* # Example
*
* ```
* // For example, to only increase the saturation of pixels that are similar to the RGB value RGB{20, 40, 60}:
* let ref_color = Rgb{20, 40, 60};
* photon::channels::selective_saturate(&mut img, ref_color, 0.1);
* ```
* @param {PhotonImage} img 
* @param {Rgb} ref_color 
* @param {number} amt 
*/
export function selective_saturate(img: PhotonImage, ref_color: Rgb, amt: number): void;
/**
* Selectively changes a pixel to greyscale if it is *not* visually similar or close to the colour specified.
* Only changes the colour of a pixel if its RGB values are within a specified range.
* 
* (Similarity between two colours is calculated via the CIE76 formula.)
* For example, if a user wishes all pixels that are *NOT* blue to be displayed in greyscale, they can selectively specify only the blue pixels to be
* kept in the photo.
* # Arguments
* * `img` - A PhotonImage.
* * `ref_color` - The `RGB` value of the reference color (to be compared to) 
* 
* # Example
*
* ```
* // For example, to greyscale all pixels that are *not* visually similar to the RGB colour RGB{20, 40, 60}:
* let ref_color = Rgb{20, 40, 60};
* photon::channels::selective_greyscale(&mut img, ref_color);
* ```
* @param {PhotonImage} photon_image 
* @param {Rgb} ref_color 
*/
export function selective_greyscale(photon_image: PhotonImage, ref_color: Rgb): void;
/**
* Apply a monochrome effect of a certain colour.
* 
* It does so by averaging the R, G, and B values of a pixel, and then adding a 
* separate value to that averaged value for each channel to produce a tint.
* # Arguments
* * `photon_image` - A PhotonImage.
* * `r_offset` - The value to add to the Red channel per pixel.
* * `g_offset` - The value to add to the Green channel per pixel.
* * `b_offset` - The value to add to the Blue channel per pixel.
*
* # Example
*
* ```
* // For example, to apply a monochrome effect to an image:
* use photon::monochrome;
* monochrome::monochroma(&mut img, 40, 50, 100);
* ```
* 
* @param {PhotonImage} photon_image 
* @param {number} r_offset 
* @param {number} g_offset 
* @param {number} b_offset 
*/
export function monochrome(photon_image: PhotonImage, r_offset: number, g_offset: number, b_offset: number): void;
/**
* Convert an image to sepia.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* // For example, to tint an image of type `PhotonImage`:
* use photon::monochrome;
* monochrome::sepia(&mut img);
* ```
* 
* @param {PhotonImage} photon_image 
*/
export function sepia(photon_image: PhotonImage): void;
/**
* Convert an image to grayscale using the conventional averaging algorithm.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* // For example, to convert an image of type `PhotonImage` to greyscale:
* use photon::monochrome;
* monochrome::grayscale(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function grayscale(photon_image: PhotonImage): void;
/**
* Convert an image to grayscale with a human corrected factor, to account for human vision.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* // For example, to convert an image of type `PhotonImage` to greyscale with a human corrected factor:
* use photon::monochrome;
* monochrome::grayscale_human_corrected(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function grayscale_human_corrected(photon_image: PhotonImage): void;
/**
* Desaturate an image by getting the min/max of each pixel\'s RGB values.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* // For example, to desaturate an image:
* use photon::monochrome;
* monochrome::desaturate(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function desaturate(photon_image: PhotonImage): void;
/**
* Uses a min. decomposition algorithm to convert an image to greyscale.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* // For example, to decompose an image with min decomposition:
* monochrome::decompose_min(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function decompose_min(photon_image: PhotonImage): void;
/**
* Uses a max. decomposition algorithm to convert an image to greyscale.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* // For example, to decompose an image with max decomposition:
* monochrome::decompose_max(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function decompose_max(photon_image: PhotonImage): void;
/**
* Employ only a limited number of gray shades in an image.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* * `num_shades` - The number of grayscale shades to be displayed in the image.
* # Example
*
* ```
* // For example, to limit an image to four shades of gray only:
* monochrome::grayscale_shades(&mut img, 4);
* ```
* @param {PhotonImage} photon_image 
* @param {number} num_shades 
*/
export function grayscale_shades(photon_image: PhotonImage, num_shades: number): void;
/**
* Convert an image to grayscale by setting a pixel\'s 3 RGB values to the Red channel\'s value.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* monochrome::r_grayscale(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function r_grayscale(photon_image: PhotonImage): void;
/**
* Convert an image to grayscale by setting a pixel\'s 3 RGB values to the Green channel\'s value.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* monochrome::g_grayscale(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function g_grayscale(photon_image: PhotonImage): void;
/**
* Convert an image to grayscale by setting a pixel\'s 3 RGB values to the Blue channel\'s value.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* # Example
*
* ```
* monochrome::b_grayscale(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function b_grayscale(photon_image: PhotonImage): void;
/**
* Convert an image to grayscale by setting a pixel\'s 3 RGB values to a chosen channel\'s value.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* * `channel` - A usize representing the channel from 0 to 2. O represents the Red channel, 1 the Green channel, and 2 the Blue channel. 
* # Example
* To grayscale using only values from the Red channel:
* ```
* monochrome::single_channel_grayscale(&mut img, 0);
* ```
* @param {PhotonImage} photon_image 
* @param {number} channel 
*/
export function single_channel_grayscale(photon_image: PhotonImage, channel: number): void;
/**
* Threshold an image using a standard thresholding algorithm.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* * `threshold` - The amount the image should be thresholded by from 0 to 255.
* # Example
*
* ```
* // For example, to threshold an image of type `PhotonImage`:
* use photon::monochrome;
* monochrome::threshold(&mut img, 30);
* ```
* @param {PhotonImage} photon_image 
* @param {number} threshold 
*/
export function threshold(photon_image: PhotonImage, threshold: number): void;
/**
* Flip an image horizontally.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* ## Example
*
* ```
* // For example, to flip an image horizontally:
* use photon::transform;
* let img = photon::open_image(\"img.jpg\");
* let new_img = photon::transform::fliph(&mut img);
* // Write the contents of this image in JPG format.
* photon::helpers::save_image(new_img, \"new_image.png\");
* ```
* @param {PhotonImage} photon_image 
*/
export function fliph(photon_image: PhotonImage): void;
/**
* Flip an image vertically.
* 
* # Arguments
* * `img` - A PhotonImage.
* 
* ## Example
*
* ```
* // For example, to flip an image vertically:
* use photon::transform;
* let img = photon::open_image(\"img.jpg\");
* let new_img = photon::transform::flipv(&mut img);
* // Write the contents of this image in JPG format.
* photon::helpers::save_image(new_img, \"new_image.png\");
* ```
* @param {PhotonImage} photon_image 
*/
export function flipv(photon_image: PhotonImage): void;
/**
* Resize an image on the web.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `width` - New width.
* * `height` - New height.
* * `sampling_filter` - Nearest = 1, Triangle = 2, CatmullRom = 3, Gaussian = 4, Lanczos3 = 5
* @param {PhotonImage} photon_img 
* @param {number} width 
* @param {number} height 
* @param {number} sampling_filter 
* @returns {any} 
*/
export function resize(photon_img: PhotonImage, width: number, height: number, sampling_filter: number): any;
/**
* Add bordered-text to an image.
* The only font available as of now is Roboto.
* Note: A graphic design/text-drawing library is currently being developed, so stay tuned.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* * `text` - Text string to be drawn to the image.
* * `x` - x-coordinate of where first letter\'s 1st pixel should be drawn.
* * `y` - y-coordinate of where first letter\'s 1st pixel should be drawn.
* 
* # Example
* ```
* // For example to draw the string \"Welcome to Photon!\" at 10, 10:
* use photon::text::draw_text_with_border;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/cats.PNG\");
* 
* draw_text_with_border(&mut img, \"Welcome to Photon!\", 10, 10);
* ```
* @param {PhotonImage} photon_img 
* @param {string} text 
* @param {number} x 
* @param {number} y 
*/
export function draw_text_with_border(photon_img: PhotonImage, text: string, x: number, y: number): void;
/**
* Add text to an image.
* The only font available as of now is Roboto.
* Note: A graphic design/text-drawing library is currently being developed, so stay tuned.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* * `text` - Text string to be drawn to the image.
* * `x` - x-coordinate of where first letter\'s 1st pixel should be drawn.
* * `y` - y-coordinate of where first letter\'s 1st pixel should be drawn.
* 
* # Example
* ```
* // For example to draw the string \"Welcome to Photon!\" at 10, 10:
* use photon::text::draw_text;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/cats.PNG\");
* 
* draw_text(&mut img, \"Welcome to Photon!\", 10, 10);
* ```
* @param {PhotonImage} photon_img 
* @param {string} text 
* @param {number} x 
* @param {number} y 
*/
export function draw_text(photon_img: PhotonImage, text: string, x: number, y: number): void;
/**
* Add a watermark to an image.
* 
* # Arguments
* * `img` - A DynamicImage that contains a view into the image.
* * `watermark` - The watermark to be placed onto the `img` image.
* * `x` - The x coordinate where the watermark\'s top corner should be positioned.
* * `y` - The y coordinate where the watermark\'s top corner should be positioned.
* # Example
*
* ```
* // For example, to add a watermark to an image at x: 30, y: 40:
* use photon::multiple;
* photon::multiple::watermark(img, watermark, 30, 40);
* ```
* @param {PhotonImage} img 
* @param {PhotonImage} watermark 
* @param {number} x 
* @param {number} y 
*/
export function watermark(img: PhotonImage, watermark: PhotonImage, x: number, y: number): void;
/**
* Blend two images together.
* The `blend_mode` (3rd param) determines which blending mode to use; change this for varying effects.
* The blend modes available include: `overlay`, `over`, `atop`, `xor`, `multiply`, `burn`, `soft_light`, `hard_light`
* `difference`, `lighten`, `darken`, `dodge`, `plus`, `exclusion` (more to come)
* NOTE: The first image must be smaller than the second image passed as params. 
* If the first image were larger than the second, then there would be overflowing pixels which would have no corresponding pixels 
* in the second image. 
* # Arguments
* * `img` - A DynamicImage that contains a view into the image.
* * `img2` - The 2nd DynamicImage to be blended with the first.
* * `blend_mode` - The blending mode to use. See above for complete list of blend modes available.
* # Example
*
* ```
* // For example, to add a watermark to an image at x: 30, y: 40:
* use photon::multiple;
* photon::multiple::watermark(img, watermark, 30, 40);
* ```
* @param {PhotonImage} photon_image 
* @param {PhotonImage} photon_image2 
* @param {string} blend_mode 
*/
export function blend(photon_image: PhotonImage, photon_image2: PhotonImage, blend_mode: string): void;
/**
* @param {number} width 
* @param {number} height 
* @returns {PhotonImage} 
*/
export function create_gradient(width: number, height: number): PhotonImage;
/**
* Apply a gradient to an image.
* @param {PhotonImage} image 
*/
export function apply_gradient(image: PhotonImage): void;
/**
* Solarization on the Blue channel.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::neue(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function neue(photon_image: PhotonImage): void;
/**
* Solarization on the Red and Green channels.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::lix(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function lix(photon_image: PhotonImage): void;
/**
* Solarization on the Red and Blue channels.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::ryo(&mut img);
* ```
* @param {PhotonImage} photon_image 
*/
export function ryo(photon_image: PhotonImage): void;
/**
* Apply a filter to an image. Over 20 filters are available.
* The filters are as follows:
* * **oceanic**: Add an aquamarine-tinted hue to an image.
* * **islands**: Aquamarine tint.
* * **marine**: Add a green/blue mixed hue to an image.
* * **seagreen**: Dark green hue, with tones of blue.
* * **flagblue**: Royal blue tint
* * **liquid**: Blue-inspired tint.
* * **diamante**: Custom filter with a blue/turquoise tint.
* * **radio**: Fallout-style radio effect.
* * **twenties**: Slight-blue tinted historical effect.
* * **rosetint**: Rose-tinted filter.
* * **mauve**: Purple-infused filter.
* * **bluechrome**: Blue monochrome effect.
* * **vintage**: Vintage filter with a red tint.
* * **perfume**: Increase the blue channel, with moderate increases in the Red and Green channels.
* * **serenity**: Custom filter with an increase in the Blue channel\'s values.
* # Arguments
* * `img` - A PhotonImage.
* * `filter_name` - The filter\'s name. Choose from the selection above, eg: \"oceanic\
* # Example
*
* ```
* // For example, to add a filter called \"vintage\" to an image:
* use photon::filters;
* photon::filters::filter(&mut img, \"vintage\");
* ```
* @param {PhotonImage} img 
* @param {string} filter_name 
*/
export function filter(img: PhotonImage, filter_name: string): void;
/**
* Apply a lofi effect to an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::lofi(&mut img);
* ```
* @param {PhotonImage} img 
*/
export function lofi(img: PhotonImage): void;
/**
* Add a rose tint to an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::pastel_pink(&mut img);
* ```
* @param {PhotonImage} img 
*/
export function pastel_pink(img: PhotonImage): void;
/**
* Apply a vintage, golden hue to an image.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::golden(&mut img);
* ```
* @param {PhotonImage} img 
*/
export function golden(img: PhotonImage): void;
/**
* Increased contrast filter effect.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::cali(&mut img);
* ```
* @param {PhotonImage} img 
*/
export function cali(img: PhotonImage): void;
/**
* Increased contrast, greyscale effect.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::dramatic(&mut img);
* ```
* @param {PhotonImage} img 
*/
export function dramatic(img: PhotonImage): void;
/**
* Apply a red hue, with increased contrast and brightness.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::firenze(&mut img);
* ```
* @param {PhotonImage} img 
*/
export function firenze(img: PhotonImage): void;
/**
* Apply a greyscale effect with increased contrast.
* 
* # Arguments
* * `img` - A PhotonImage.
* # Example
*
* ```
* photon::filters::obsidian(&mut img);
* ```
* @param {PhotonImage} img 
*/
export function obsidian(img: PhotonImage): void;
/**
* Apply gamma correction. 
* Image manipulation effects in the LCh colour space
* 
* Effects include:
* * **saturate** - Saturation increase.
* * **desaturate** - Desaturate the image.
* * **shift_hue** - Hue rotation by a specified number of degrees.
* * **darken** - Decrease the brightness.
* * **lighten** - Increase the brightness.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* * `mode` - The effect desired to be applied. Choose from: `saturate`, `desaturate`, `shift_hue`, `darken`, `lighten`
* * `amt` - A float value from 0 to 1 which represents the amount the effect should be increased by.
* # Example
* ```
* // For example to increase the saturation by 10%:
* use photon::color_spaces::lch;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* lch(&mut img, \"saturate\", 0.1);
* ```
* @param {PhotonImage} photon_image 
* @param {string} mode 
* @param {number} amt 
*/
export function lch(photon_image: PhotonImage, mode: string, amt: number): void;
/**
* Image manipulation effects in the HSL colour space.
* 
* Effects include:
* * **saturate** - Saturation increase.
* * **desaturate** - Desaturate the image.
* * **shift_hue** - Hue rotation by a specified number of degrees.
* * **darken** - Decrease the brightness.
* * **lighten** - Increase the brightness.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* * `mode` - The effect desired to be applied. Choose from: `saturate`, `desaturate`, `shift_hue`, `darken`, `lighten`
* * `amt` - A float value from 0 to 1 which represents the amount the effect should be increased by.
* # Example
* ```
* // For example to increase the saturation by 10%:
* use photon::color_spaces::hsl;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* hsl(&mut img, \"saturate\", 0.1);
* ``` 
* @param {PhotonImage} photon_image 
* @param {string} mode 
* @param {number} amt 
*/
export function hsl(photon_image: PhotonImage, mode: string, amt: number): void;
/**
* Image manipulation in the HSV colour space. 
* 
* Effects include:
* * **saturate** - Saturation increase.
* * **desaturate** - Desaturate the image.
* * **shift_hue** - Hue rotation by a specified number of degrees.
* * **darken** - Decrease the brightness.
* * **lighten** - Increase the brightness.
* 
* # Arguments
* * `photon_image` - A PhotonImage.
* * `mode` - The effect desired to be applied. Choose from: `saturate`, `desaturate`, `shift_hue`, `darken`, `lighten`
* * `amt` - A float value from 0 to 1 which represents the amount the effect should be increased by.
* 
* # Example
* ```
* // For example to increase the saturation by 10%:
* use photon::color_spaces::hsv;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* hsv(&mut img, \"saturate\", 0.1);
* ```
* @param {PhotonImage} photon_image 
* @param {string} mode 
* @param {number} amt 
*/
export function hsv(photon_image: PhotonImage, mode: string, amt: number): void;
/**
* Shift hue by a specified number of degrees in the HSL colour space.
* # Arguments
* * `img` - A PhotonImage.
* * `mode` - A float value from 0 to 1 which is the amount to shift the hue by, or hue rotate by.
* 
* # Example
* ```
* // For example to hue rotate/shift the hue by 120 degrees in the HSL colour space:
* use photon::color_spaces::hue_rotate_hsl;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* hue_rotate_hsl(&mut img, 120);
* ``` 
* @param {PhotonImage} img 
* @param {number} degrees 
*/
export function hue_rotate_hsl(img: PhotonImage, degrees: number): void;
/**
* Shift hue by a specified number of degrees in the HSV colour space.
* # Arguments
* * `img` - A PhotonImage.
* * `mode` - A float value from 0 to 1 which is the amount to shift the hue by, or hue rotate by.
* 
* # Example
* ```
* // For example to hue rotate/shift the hue by 120 degrees in the HSV colour space:
* use photon::color_spaces::hue_rotate_hsv;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* hue_rotate_hsv(&mut img, 120);
* ``` 
* @param {PhotonImage} img 
* @param {number} degrees 
*/
export function hue_rotate_hsv(img: PhotonImage, degrees: number): void;
/**
* Shift hue by a specified number of degrees in the LCh colour space.
* # Arguments
* * `img` - A PhotonImage.
* * `mode` - A float value from 0 to 1 which is the amount to shift the hue by, or hue rotate by.
* 
* # Example
* ```
* // For example to hue rotate/shift the hue by 120 degrees in the HSL colour space:
* use photon::color_spaces::hue_rotate_lch;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* hue_rotate_lch(&mut img, 120);
* ``` 
* @param {PhotonImage} img 
* @param {number} degrees 
*/
export function hue_rotate_lch(img: PhotonImage, degrees: number): void;
/**
* Increase the image\'s saturation by converting each pixel\'s colour to the HSL colour space
* and increasing the colour\'s saturation. 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to increase the saturation by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Increasing saturation by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to increase saturation by 10% in the HSL colour space:
* use photon::color_spaces::saturate_hsl;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* saturate_hsl(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function saturate_hsl(img: PhotonImage, level: number): void;
/**
* Increase the image\'s saturation in the LCh colour space.
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to increase the saturation by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Increasing saturation by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to increase saturation by 40% in the Lch colour space:
* use photon::color_spaces::saturate_lch;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* saturate_lch(&mut img, 0.4);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function saturate_lch(img: PhotonImage, level: number): void;
/**
* Increase the image\'s saturation in the HSV colour space.
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level by which to increase the saturation by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Increasing saturation by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to increase saturation by 30% in the HSV colour space:
* use photon::color_spaces::saturate_hsv;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* saturate_hsv(&mut img, 0.3);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function saturate_hsv(img: PhotonImage, level: number): void;
/**
* Lighten an image by a specified amount in the LCh colour space.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to lighten the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Lightening by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to lighten an image by 10% in the LCh colour space:
* use photon::color_spaces::lighten_lch;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* lighten_lch(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function lighten_lch(img: PhotonImage, level: number): void;
/**
* Lighten an image by a specified amount in the HSL colour space.
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to lighten the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Lightening by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to lighten an image by 10% in the HSL colour space:
* use photon::color_spaces::lighten_hsl;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* lighten_hsl(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function lighten_hsl(img: PhotonImage, level: number): void;
/**
* Lighten an image by a specified amount in the HSV colour space.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to lighten the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Lightening by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to lighten an image by 10% in the HSV colour space:
* use photon::color_spaces::lighten_hsv;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* lighten_hsv(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function lighten_hsv(img: PhotonImage, level: number): void;
/**
* Darken the image by a specified amount in the LCh colour space.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to darken the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Darkening by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to darken an image by 10% in the LCh colour space:
* use photon::color_spaces::darken_lch;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* darken_lch(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function darken_lch(img: PhotonImage, level: number): void;
/**
* Darken the image by a specified amount in the HSL colour space.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to darken the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Darkening by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to darken an image by 10% in the HSL colour space:
* use photon::color_spaces::darken_hsl;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* darken_hsl(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function darken_hsl(img: PhotonImage, level: number): void;
/**
* Darken the image\'s colours by a specified amount in the HSV colour space.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to darken the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Darkening by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to darken an image by 10% in the HSV colour space:
* use photon::color_spaces::darken_hsv;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* darken_hsv(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function darken_hsv(img: PhotonImage, level: number): void;
/**
* Desaturate the image by a specified amount in the HSV colour space.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to desaturate the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Desaturating by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to desaturate an image by 10% in the HSV colour space:
* use photon::color_spaces::desaturate_hsv;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/mountains.PNG\");
* 
* desaturate_hsv(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function desaturate_hsv(img: PhotonImage, level: number): void;
/**
* Desaturate the image by a specified amount in the HSL colour space.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to desaturate the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Desaturating by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to desaturate an image by 10% in the LCh colour space:
* use photon::color_spaces::desaturate_hsl;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* desaturate_hsl(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function desaturate_hsl(img: PhotonImage, level: number): void;
/**
* Desaturate the image by a specified amount in the LCh colour space.
* 
* # Arguments
* * `img` - A PhotonImage.
* * `level` - Float value from 0 to 1 representing the level to which to desaturate the image by.
* The `level` must be from 0 to 1 in floating-point, `f32` format. 
* Desaturating by 80% would be represented by a `level` of 0.8
* 
* # Example
* ```
* // For example to desaturate an image by 10% in the LCh colour space:
* use photon::color_spaces::desaturate_lch;
* 
* // Open the image. A PhotonImage is returned.
* let img: PhotonImage = open_image(\"images/flowers.PNG\");
* 
* desaturate_lch(&mut img, 0.1);
* ``` 
* @param {PhotonImage} img 
* @param {number} level 
*/
export function desaturate_lch(img: PhotonImage, level: number): void;
/**
* Mix image with a single color, supporting passing `opacity`.
* The algorithm comes from Jimp. See `function mix` and `function colorFn` at following link:
* https://github.com/oliver-moran/jimp/blob/29679faa597228ff2f20d34c5758e4d2257065a3/packages/plugin-color/src/index.js
* Specifically, result_value = (mix_color_value - origin_value) * opacity + origin_value =
* mix_color_value * opacity + (1 - opacity) * origin_value for each
* of RGB channel.
*
* # Arguments
* * `photon_image` - A PhotonImage that contains a view into the image.
* * `mix_color` - the color to be mixed in, as an RGB value.
* * `opacity` - the opacity of color when mixed to image. Float value from 0 to 1.
* # Example
*
* ```
* // For example, to mix an image with rgb (50, 255, 254) and opacity 0.4:
* use photon::colour_spaces::mix_with_colour;
*
* let mix_colour = Rgb{50, 255, 254};
* mix_with_colour(photon_image, mix_colour, 0.4);
* ```
* @param {PhotonImage} photon_image 
* @param {Rgb} mix_colour 
* @param {number} opacity 
*/
export function mix_with_colour(photon_image: PhotonImage, mix_colour: Rgb, opacity: number): void;
/**
* [temp] Check if WASM is supported.
*/
export function run(): void;
/**
* Get the ImageData from a 2D canvas context
* @param {any} canvas 
* @param {any} ctx 
* @returns {any} 
*/
export function get_image_data(canvas: any, ctx: any): any;
/**
* Place a PhotonImage onto a 2D canvas.
* @param {any} canvas 
* @param {any} ctx 
* @param {PhotonImage} new_image 
*/
export function putImageData(canvas: any, ctx: any, new_image: PhotonImage): void;
/**
* Convert a HTML5 Canvas Element to a PhotonImage.
* 
* This converts the ImageData found in the canvas context to a PhotonImage,
* which can then have effects or filters applied to it.
* @param {any} canvas 
* @param {any} ctx 
* @returns {PhotonImage} 
*/
export function open_image(canvas: any, ctx: any): PhotonImage;
/**
* Convert ImageData to a raw pixel vec of u8s.
* @param {any} imgdata 
* @returns {Uint8Array} 
*/
export function to_raw_pixels(imgdata: any): Uint8Array;
/**
* Convert a base64 string to a PhotonImage.
* @param {string} base64 
* @returns {PhotonImage} 
*/
export function base64_to_image(base64: string): PhotonImage;
/**
* Convert a base64 string to a Vec of u8s.
* @param {string} base64 
* @returns {Uint8Array} 
*/
export function base64_to_vec(base64: string): Uint8Array;
/**
* Convert a PhotonImage to JS-compatible ImageData.
* @param {PhotonImage} photon_image 
* @returns {any} 
*/
export function to_image_data(photon_image: PhotonImage): any;
/**
* Adds an offset to the image by a certain number of pixels. 
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* * `offset` - The offset is added to the pixels in the image.  
* # Example
*
* ```
* // For example, to offset pixels by 30 pixels on the red channel:
* use photon::effects;
* photon::effects::offset(img, 0, 30);
* ```
* @param {PhotonImage} photon_image 
* @param {number} channel_index 
* @param {number} offset 
*/
export function offset(photon_image: PhotonImage, channel_index: number, offset: number): void;
/**
* Adds an offset to the red channel by a certain number of pixels. 
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* * `offset` - The offset you want to move the red channel by. 
* # Example
*
* ```
* // For example, to add an offset to the red channel by 30 pixels.
* use photon::effects;
* photon::effects::offset_red(img, 30);
* ```
* @param {PhotonImage} img 
* @param {number} offset_amt 
*/
export function offset_red(img: PhotonImage, offset_amt: number): void;
/**
* Adds an offset to the green channel by a certain number of pixels. 
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* * `offset` - The offset you want to move the green channel by.
* # Example
*
* ```
* // For example, to add an offset to the green channel by 30 pixels.
* use photon::effects;
* photon::effects::offset_green(img, 40);
* ```
* @param {PhotonImage} img 
* @param {number} offset_amt 
*/
export function offset_green(img: PhotonImage, offset_amt: number): void;
/**
* Adds an offset to the blue channel by a certain number of pixels. 
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* * `offset_amt` - The offset you want to move the blue channel by.
* # Example
* // For example, to add an offset to the green channel by 40 pixels.
* use photon::effects;
* photon::effects::offset_blue(img, 40);
* ```
* @param {PhotonImage} img 
* @param {number} offset_amt 
*/
export function offset_blue(img: PhotonImage, offset_amt: number): void;
/**
* Adds multiple offsets to the image by a certain number of pixels (on two channels).
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* * `offset` - The offset is added to the pixels in the image.  
* # Example
*
* ```
* // For example, to add a 30-pixel offset to both the red and blue channels:
* use photon::effects;
* photon::effects::multiple_offsets(img, 30, 0, 2);
* ```
* @param {PhotonImage} photon_image 
* @param {number} offset 
* @param {number} channel_index 
* @param {number} channel_index2 
*/
export function multiple_offsets(photon_image: PhotonImage, offset: number, channel_index: number, channel_index2: number): void;
/**
* Reduces an image to the primary colours.
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* # Example
*
* ```
* // For example, to add a primary colour effect to an image of type `DynamicImage`:
* use photon::effects;
* photon::effects::primary(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function primary(photon_image: PhotonImage): void;
/**
* Colorizes the green channels of the image.
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* # Example
*
* ```
* // For example, to colorize an image of type `PhotonImage`:
* use photon::effects;
* photon::effects::colorize(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function colorize(photon_image: PhotonImage): void;
/**
* Applies a solarizing effect to an image.
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* # Example
*
* ```
* // For example, to colorize an image of type `PhotonImage`:
* use photon::effects;
* photon::effects::solarize(img);
* ```
* @param {PhotonImage} photon_image 
*/
export function solarize(photon_image: PhotonImage): void;
/**
* Applies a solarizing effect to an image and returns the resulting PhotonImage.
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* # Example
*
* ```
* // For example, to solarize an image of type `PhotonImage`:
* use photon::effects;
* let img = photon::effects::solarize(img);
* ```
* @param {PhotonImage} photon_image 
* @returns {PhotonImage} 
*/
export function solarize_retimg(photon_image: PhotonImage): PhotonImage;
/**
* Increase the brightness of an image by a factor.
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* * `brightness` - A u8 to add to the brightness.
* # Example
*
* ```
* photon::effects::inc_brightness(img, 10);
* ```
* @param {PhotonImage} photon_image 
* @param {number} brightness 
*/
export function inc_brightness(photon_image: PhotonImage, brightness: number): void;
/**
* Adjust the contrast of an image by a factor.
*
* # Arguments
* * `photon_image` - A PhotonImage that contains a view into the image.
* * `contrast` - An f32 factor used to adjust contrast. Between [-255.0, 255.0]. The algorithm will
* clamp results if passed factor is out of range.
* # Example
*
* ```
* photon::effects::adjust_contrast(photon_image, 30.0);
* ```
* @param {PhotonImage} photon_image 
* @param {number} contrast 
*/
export function adjust_contrast(photon_image: PhotonImage, contrast: number): void;
/**
* Tint an image by adding an offset to averaged RGB channel values.
* 
* # Arguments
* * `img` - A PhotonImage that contains a view into the image.
* * `r_offset` - The amount the  R channel should be incremented by.
* * `g_offset` - The amount the G channel should be incremented by.
* * `b_offset` - The amount the B channel should be incremented by.
* # Example
*
* ```
* // For example, to tint an image of type `PhotonImage`:
* photon::tint(img, 10, 20, 15);
* ```
* 
* @param {PhotonImage} photon_image 
* @param {number} r_offset 
* @param {number} g_offset 
* @param {number} b_offset 
*/
export function tint(photon_image: PhotonImage, r_offset: number, g_offset: number, b_offset: number): void;
/**
* Horizontal strips. Divide an image into a series of equal-height strips, for an artistic effect.
* @param {PhotonImage} photon_image 
* @param {number} num_strips 
*/
export function horizontal_strips(photon_image: PhotonImage, num_strips: number): void;
/**
* Vertical strips. Divide an image into a series of equal-width strips, for an artistic effect.
* @param {PhotonImage} photon_image 
* @param {number} num_strips 
*/
export function vertical_strips(photon_image: PhotonImage, num_strips: number): void;
export enum SamplingFilter {
  Nearest,
  Triangle,
  CatmullRom,
  Gaussian,
  Lanczos3,
}
/**
*/
/**
* Provides the image\'s height, width, and contains the image\'s raw pixels.
* For use when communicating between JS and WASM, and also natively. 
*/
export class PhotonImage {
  free(): void;
/**
* Create a new PhotonImage from a Vec of u8s, which represent raw pixels.
* @param {Uint8Array} raw_pixels 
* @param {number} width 
* @param {number} height 
*/
  constructor(raw_pixels: Uint8Array, width: number, height: number);
/**
* Create a new PhotonImage from a base64 string.
* @param {string} base64 
* @returns {PhotonImage} 
*/
  static new_from_base64(base64: string): PhotonImage;
/**
* Create a new PhotonImage from a byteslice.
* @param {Uint8Array} vec 
* @returns {PhotonImage} 
*/
  static new_from_byteslice(vec: Uint8Array): PhotonImage;
/**
* Get the width of the PhotonImage.
* @returns {number} 
*/
  get_width(): number;
/**
* Get the PhotonImage\'s pixels as a Vec of u8s.
* @returns {Uint8Array} 
*/
  get_raw_pixels(): Uint8Array;
/**
* Get the height of the PhotonImage.
* @returns {number} 
*/
  get_height(): number;
/**
* Convert the PhotonImage to base64.
* @returns {string} 
*/
  get_base64(): string;
/**
* Convert the PhotonImage\'s raw pixels to JS-compatible ImageData.
* @returns {any} 
*/
  get_image_data(): any;
/**
* Convert ImageData to raw pixels, and update the PhotonImage\'s raw pixels to this.
* @param {any} img_data 
*/
  set_imgdata(img_data: any): void;
}
/**
* RGB color type.
*/
export class Rgb {
  free(): void;
/**
* Create a new RGB struct.
* @param {number} r 
* @param {number} g 
* @param {number} b 
*/
  constructor(r: number, g: number, b: number);
/**
* Set the Red value.
* @param {number} r 
*/
  set_red(r: number): void;
/**
* Get the Green value.
* @param {number} g 
*/
  set_green(g: number): void;
/**
* Set the Blue value.
* @param {number} b 
*/
  set_blue(b: number): void;
/**
* Get the Red value.
* @returns {number} 
*/
  get_red(): number;
/**
* Get the Green value.
* @returns {number} 
*/
  get_green(): number;
/**
* Get the Blue value.
* @returns {number} 
*/
  get_blue(): number;
}
